package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcZhongdianWork;

/**
 * 重点工作项目Service接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface ITcZhongdianWorkService 
{
    /**
     * 查询重点工作项目
     * 
     * @param id 重点工作项目主键
     * @return 重点工作项目
     */
    public TcZhongdianWork selectTcZhongdianWorkById(Long id);

    /**
     * 查询重点工作项目列表
     * 
     * @param tcZhongdianWork 重点工作项目
     * @return 重点工作项目集合
     */
    public List<TcZhongdianWork> selectTcZhongdianWorkList(TcZhongdianWork tcZhongdianWork);

    /**
     * 新增重点工作项目
     * 
     * @param tcZhongdianWork 重点工作项目
     * @return 结果
     */
    public int insertTcZhongdianWork(TcZhongdianWork tcZhongdianWork);

    /**
     * 修改重点工作项目
     * 
     * @param tcZhongdianWork 重点工作项目
     * @return 结果
     */
    public int updateTcZhongdianWork(TcZhongdianWork tcZhongdianWork);

    /**
     * 批量删除重点工作项目
     * 
     * @param ids 需要删除的重点工作项目主键集合
     * @return 结果
     */
    public int deleteTcZhongdianWorkByIds(Long[] ids);

    /**
     * 删除重点工作项目信息
     * 
     * @param id 重点工作项目主键
     * @return 结果
     */
    public int deleteTcZhongdianWorkById(Long id);
}
